@@ -4,12 +4,19 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 
+import decimal
+
 
 # Module API
 
 def check_maximum(constraint, value):
     if value is None:
         return True
-    if value <= constraint:
-        return True
+    try:
+        if value <= constraint:
+            return True
+    except decimal.InvalidOperation:
+        # For non-finite numbers NaN, INF and -INF
+        # the constraint always is not satisfied
+        return False
     return False
